from setuptools import setup
setup(
    name='testprodgekt',
    version='1.1',
    packages = ['testprodgekt'],
    install_requires=['keyboard'],
    python_requires=">=3.11",
    author="DavidYdin",
    author_email="David.2280@yandex.ru"
)